@@ -45,6 +45,7 @@ from .client import (
     PantherSDKBulkUploadResponse,
     UpdateManagedSchemaParams,
     UpdateManagedSchemaResponse,
+    backend_response_failed,
 )
 
 LAMBDA_CLIENT_NAME = "lambda"
@@ -91,7 +92,7 @@ class LambdaClient(Client):
         return BackendCheckResponse(success=True, message="not implemented")
 
     def bulk_upload(self, params: BulkUploadParams) -> BackendResponse[BulkUploadResponse]:
-        res = self._parse_response(
+        resp = self._parse_response(
             self._lambda_client.invoke(
                 FunctionName="panther-analysis-api",
                 InvocationType="RequestResponse",
@@ -107,12 +108,17 @@ class LambdaClient(Client):
             )
         )
 
-        body = decode_body(res)
+        if backend_response_failed(resp):
+            err = BackendError(resp.data)
+            err.permanent = True
+            raise err
+
+        body = decode_body(resp)
 
         default_stats = dict(total=0, new=0, modified=0)
 
         return BackendResponse(
-            status_code=res.status_code,
+            status_code=resp.status_code,
             data=BulkUploadResponse(
                 rules=BulkUploadStatistics(**body.get("rules", default_stats)),
                 policies=BulkUploadStatistics(**body.get("policies", default_stats)),
@@ -263,7 +269,7 @@ class LambdaClient(Client):
     def panthersdk_bulk_upload(
         self, params: PantherSDKBulkUploadParams
     ) -> BackendResponse[PantherSDKBulkUploadResponse]:
-        res = self._parse_response(
+        resp = self._parse_response(
             self._lambda_client.invoke(
                 FunctionName="panther-analysis-api",
                 InvocationType="RequestResponse",
@@ -280,11 +286,17 @@ class LambdaClient(Client):
                 ),
             )
         )
-        body = decode_body(res)
+
+        if backend_response_failed(resp):
+            err = BackendError(resp.data)
+            err.permanent = True
+            raise err
+
+        body = decode_body(resp)
         default_stats = dict(total=0, new=0, modified=0)
 
         return BackendResponse(
-            status_code=res.status_code,
+            status_code=resp.status_code,
             data=PantherSDKBulkUploadResponse(
                 rules=BulkUploadStatistics(**body.get("rules", default_stats)),
                 policies=BulkUploadStatistics(**body.get("policies", default_stats)),
