@@ -43,7 +43,7 @@ from datetime import datetime
 from distutils.util import strtobool  # pylint: disable=E0611, E0401
 from fnmatch import fnmatch
 from importlib.abc import Loader
-from typing import Any, DefaultDict, Dict, Iterator, List, Set, Tuple, Type
+from typing import Any, DefaultDict, Dict, Final, Iterator, List, Set, Tuple, Type
 from unittest.mock import MagicMock, patch
 from uuid import uuid4
 
@@ -99,6 +99,8 @@ from panther_analysis_tool.schemas import (
 )
 from panther_analysis_tool.util import func_with_backend, get_client
 
+VERSION_STRING: Final = "panther_analysis_tool 0.17.2"
+
 CONFIG_FILE = ".panther_settings.yml"
 DATA_MODEL_LOCATION = "./data_models"
 HELPERS_LOCATION = "./global_helpers"
@@ -1473,7 +1475,7 @@ def setup_parser() -> argparse.ArgumentParser:
         + "managing Panther policies and rules.",
         prog="panther_analysis_tool",
     )
-    parser.add_argument("--version", action="version", version="panther_analysis_tool 0.17.1")
+    parser.add_argument("--version", action="version", version=VERSION_STRING)
     parser.add_argument("--debug", action="store_true", dest="debug")
     subparsers = parser.add_subparsers()
 
